@@ -15,10 +15,12 @@ We return "/etc/pki/tls/certs/ca-bundle.crt" provided by the ca-certificates
 package.
 """
 
-
-def where():
-    """ Don't use the certs bundled with requests, use ca-certificates. """
-    return "/etc/pki/tls/certs/ca-bundle.crt"
+try:
+    from certifi import where
+except ImportError:
+    def where():
+        """ Don't use the certs bundled with requests, use ca-certificates. """
+        return "/etc/pki/tls/certs/ca-bundle.crt"
 
 if __name__ == '__main__':
     print(where())
